.. image:: https://travis-ci.com/zhengp0/xspline.svg?branch=main
    :target: https://travis-ci.com/zhengp0/xspline

.. image:: https://badge.fury.io/py/xspline.svg
    :target: https://badge.fury.io/py/xspline

XSpline
=======

Advanced spline package that provides b-spline bases, their derivatives and integrals.
